@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2007-2015 Contributors as noted in the AUTHORS file
+    Copyright (c) 2007-2016 Contributors as noted in the AUTHORS file
 
     This file is part of libzmq, the ZeroMQ core engine in C++.
 
@@ -30,14 +30,18 @@
 #ifndef __TESTUTIL_HPP_INCLUDED__
 #define __TESTUTIL_HPP_INCLUDED__
 
+#if defined ZMQ_CUSTOM_PLATFORM_HPP
+#   include "platform.hpp"
+#else
+#   include "../src/platform.hpp"
+#endif
 #include "../include/zmq.h"
 #include "../src/stdint.hpp"
-#include "platform.hpp"
 
 //  This defines the settle time used in tests; raise this if we
 //  get test failures on slower systems due to binds/connects not
 //  settled. Tested to work reliably at 1 msec on a fast PC.
-#define SETTLE_TIME 10         //  In msec
+#define SETTLE_TIME 300         //  In msec
 
 #undef NDEBUG
 #include <time.h>
@@ -47,12 +51,17 @@
 #include <string.h>
 
 #if defined _WIN32
-#   include "windows.hpp"
+#   include "../src/windows.hpp"
 #   if defined _MSC_VER
 #       include <crtdbg.h>
 #       pragma warning(disable:4996)
+// iphlpapi is needed for if_nametoindex (not on Windows XP)
+#       if !defined ZMQ_HAVE_WINDOWS_TARGET_XP
+#           pragma comment(lib,"iphlpapi")
+#       endif
 #   endif
 #else
+#   include <pthread.h>
 #   include <unistd.h>
 #   include <signal.h>
 #   include <stdlib.h>
@@ -60,11 +69,14 @@
 #   include <sys/socket.h>
 #   include <netinet/in.h>
 #   include <arpa/inet.h>
+#   if defined (ZMQ_HAVE_AIX)
+#      include <sys/types.h>
+#      include <sys/socketvar.h>
+#   endif
 #endif
 
 //  Bounce a message from client to server and back
 //  For REQ/REP or DEALER/DEALER pairs only
-
 void
 bounce (void *server, void *client)
 {
@@ -120,7 +132,6 @@ bounce (void *server, void *client)
 
 //  Same as bounce, but expect messages to never arrive
 //  for security or subscriber reasons.
-
 void
 expect_bounce_fail (void *server, void *client)
 {
@@ -197,7 +208,9 @@ const char *SEQ_END = (const char *) 1;
 //  Sends a message composed of frames that are C strings or null frames.
 //  The list must be terminated by SEQ_END.
 //  Example: s_send_seq (req, "ABC", 0, "DEF", SEQ_END);
-void s_send_seq (void *socket, ...)
+
+void
+s_send_seq (void *socket, ...)
 {
     va_list ap;
     va_start (ap, socket);
@@ -226,7 +239,9 @@ void s_send_seq (void *socket, ...)
 //  the given data which can be either C strings or 0 for a null frame.
 //  The list must be terminated by SEQ_END.
 //  Example: s_recv_seq (rep, "ABC", 0, "DEF", SEQ_END);
-void s_recv_seq (void *socket, ...)
+
+void
+s_recv_seq (void *socket, ...)
 {
     zmq_msg_t msg;
     zmq_msg_init (&msg);
@@ -264,7 +279,8 @@ void s_recv_seq (void *socket, ...)
 
 
 //  Sets a zero linger period on a socket and closes it.
-void close_zero_linger (void *socket)
+void
+close_zero_linger (void *socket)
 {
     int linger = 0;
     int rc = zmq_setsockopt (socket, ZMQ_LINGER, &linger, sizeof(linger));
@@ -273,7 +289,8 @@ void close_zero_linger (void *socket)
     assert (rc == 0);
 }
 
-void setup_test_environment()
+void
+setup_test_environment (void)
 {
 #if defined _WIN32
 #   if defined _MSC_VER
@@ -282,8 +299,15 @@ void setup_test_environment()
     _CrtSetReportFile( _CRT_ASSERT, _CRTDBG_FILE_STDERR );
 #   endif
 #else
+#if defined ZMQ_HAVE_CYGWIN
+    // abort test after 121 seconds
+    alarm(121);
+#else
+#   if !defined ZMQ_DISABLE_TEST_TIMEOUT
     // abort test after 60 seconds
     alarm(60);
+#   endif
+#endif
 #endif
 #if defined __MVS__
     // z/OS UNIX System Services: Ignore SIGPIPE during test runs, as a
@@ -293,8 +317,11 @@ void setup_test_environment()
 }
 
 //  Provide portable millisecond sleep
-// http://www.cplusplus.com/forum/unices/60161/    http://en.cppreference.com/w/cpp/thread/sleep_for
-void msleep (int milliseconds)
+//  http://www.cplusplus.com/forum/unices/60161/
+//  http://en.cppreference.com/w/cpp/thread/sleep_for
+
+void
+msleep (int milliseconds)
 {
 #ifdef ZMQ_HAVE_WINDOWS
     Sleep (milliseconds);
@@ -308,6 +335,9 @@ void msleep (int milliseconds)
 int
 is_ipv6_available(void)
 {
+#if defined (ZMQ_HAVE_WINDOWS) && (_WIN32_WINNT < 0x0600)
+    return 0;
+#else
     int rc, ipv6 = 1;
     struct sockaddr_in6 test_addr;
 
@@ -350,6 +380,7 @@ is_ipv6_available(void)
 #endif
 
     return ipv6;
+#endif // _WIN32_WINNT < 0x0600
 }
 
 #endif
